AnchorSearcher
==============

.. currentmodule:: pykeen.nn.node_piece

.. autoclass:: AnchorSearcher
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~AnchorSearcher.__call__
      ~AnchorSearcher.extra_repr

   .. rubric:: Methods Documentation

   .. automethod:: __call__
   .. automethod:: extra_repr
